@@ -2,7 +2,12 @@
 mod tracer;
 pub use tracer::Tracer;
 
+pub mod tracing_macros {
+    pub use tracing::{trace_span, info_span, debug_span, warn_span, error_span};
+}
+
 // trace object implements the `Tracer` trait
+#[macro_use]
 mod trace;
 pub use trace::Trace;
 
